@@ -1,5 +1,6 @@
 import cherrypy
 
+from .exceptions import AuthenticationError, MissingAuthenticatorError, WrongIdentityClassError
 from .utils import redirect
 from ._constants import (
     AUTHENTICATOR,
@@ -9,7 +10,7 @@ from ._constants import (
 )
 
 
-class Identity:
+class Identity(object):
     """
     Provides an abstraction for the logged in user data to be stored in the session
     """
@@ -25,10 +26,6 @@ class Identity:
         self.data = data
 
 
-class AuthenticationError(Exception):
-    pass
-
-
 def is_authenticated():
     """
     Tells whether the user is authenticated or not
@@ -38,10 +35,13 @@ def is_authenticated():
     if not USER_SESSION_KEY in cherrypy.session:
         return False
 
-    current_user = cherrypy.session[USER_SESSION_KEY]
+    user = cherrypy.session[USER_SESSION_KEY]
 
-    if not isinstance(current_user, Identity):
-        raise Exception('Wrong identity model')
+    if not user:
+        return False
+
+    if not isinstance(user, Identity):
+        raise WrongIdentityClassError()
 
     return True
 
@@ -58,12 +58,12 @@ def authenticate(**credentials):
     authenticator = cherrypy.request.config.get(AUTHENTICATOR, None)
 
     if not authenticator:
-        raise Exception('Cannot authenticate without an auth function')
+        raise MissingAuthenticatorError()
 
     user = authenticator(**credentials)
 
     if not isinstance(user, Identity):
-        raise Exception('Authenticator function must return \'Identity\' object')
+        raise WrongIdentityClassError()
 
     if not user:
         raise AuthenticationError()
@@ -72,7 +72,7 @@ def authenticate(**credentials):
     return user
 
 
-class AuthControllerDefaultDispatcher:
+class AuthControllerDefaultDispatcher(object):
     """
     Provides a default authentication controller for the default dispatcher
     """
@@ -94,14 +94,14 @@ class AuthControllerDefaultDispatcher:
 
 import sys
 if sys.version_info < (3,):  # Python2
-    class _Login:
+    class _Login(object):
         exposed = True
 
         def POST(self, _next=None, **credentials):
             authenticate(**credentials)
             redirect(_next, LOGIN_REDIRECT)
 
-    class _Logout:
+    class _Logout(object):
         exposed = True
 
         def POST(self, _next=None):
@@ -109,6 +109,7 @@ if sys.version_info < (3,):  # Python2
             cherrypy.lib.sessions.expire()
 
             redirect(_next, LOGOUT_REDIRECT)
+
 else:  # Python3
     class _Login:
         exposed = True
@@ -119,7 +120,7 @@ else:  # Python3
         POST = AuthControllerDefaultDispatcher.logout
 
 
-class AuthControllerMethodDispatcher:
+class AuthControllerMethodDispatcher(object):
     """
     Provides a default authentication controller for the method dispatcher
     """
